bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaISOToGaussianGammaARD

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaISOToGaussianGammaARD.__init__
      ~GaussianGammaISOToGaussianGammaARD.add_plate_axis
      ~GaussianGammaISOToGaussianGammaARD.broadcasting_multiplier
      ~GaussianGammaISOToGaussianGammaARD.delete
      ~GaussianGammaISOToGaussianGammaARD.get_mask
      ~GaussianGammaISOToGaussianGammaARD.get_moments
      ~GaussianGammaISOToGaussianGammaARD.get_shape
      ~GaussianGammaISOToGaussianGammaARD.has_plotter
      ~GaussianGammaISOToGaussianGammaARD.lower_bound_contribution
      ~GaussianGammaISOToGaussianGammaARD.move_plates
      ~GaussianGammaISOToGaussianGammaARD.plot
      ~GaussianGammaISOToGaussianGammaARD.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaISOToGaussianGammaARD.plates
      ~GaussianGammaISOToGaussianGammaARD.plates_multiplier
   
   